summaryrefslogtreecommitdiff
path: root/pylint/__init__.py
diff options
context:
space:
mode:
authorDaniƫl van Noord <13665637+DanielNoord@users.noreply.github.com>2021-12-31 10:46:31 +0100
committerGitHub <noreply@github.com>2021-12-31 10:46:31 +0100
commitcf17a454ffb0b5ee47babfc537bdf782a1915da6 (patch)
treed26ba5c0675014fe1b4a41aa7d295a7a6dca1881 /pylint/__init__.py
parentb9fe59736d1c272b2e722a352f281d6686cc40ac (diff)
downloadpylint-git-cf17a454ffb0b5ee47babfc537bdf782a1915da6.tar.gz
Rename ``arguments`` to ``argv`` in entry point functions (#5619)
Co-authored-by: Marc Mueller <30130371+cdce8p@users.noreply.github.com>
Diffstat (limited to 'pylint/__init__.py')
-rw-r--r--pylint/__init__.py20
1 files changed, 10 insertions, 10 deletions
diff --git a/pylint/__init__.py b/pylint/__init__.py
index 53ea308bd..d758a0db0 100644
--- a/pylint/__init__.py
+++ b/pylint/__init__.py
@@ -11,22 +11,22 @@
import os
import sys
-from typing import List, Optional
+from typing import Optional, Sequence
from pylint.__pkginfo__ import __version__
# pylint: disable=import-outside-toplevel
-def run_pylint(*, arguments: Optional[List[str]] = None):
+def run_pylint(argv: Optional[Sequence[str]] = None):
"""Run pylint
Arguments can be a list of strings normally supplied as arguments on the command line
"""
from pylint.lint import Run as PylintRun
try:
- PylintRun(arguments or sys.argv[1:])
+ PylintRun(argv or sys.argv[1:])
except KeyboardInterrupt:
sys.exit(1)
@@ -37,24 +37,24 @@ def run_epylint():
EpylintRun()
-def run_pyreverse(*, arguments: Optional[List[str]] = None):
+def run_pyreverse(argv: Optional[Sequence[str]] = None):
"""Run pyreverse
Arguments can be a list of strings normally supplied as arguments on the command line
"""
from pylint.pyreverse.main import Run as PyreverseRun
- PyreverseRun(arguments or sys.argv[1:])
+ PyreverseRun(argv or sys.argv[1:])
-def run_symilar(*, arguments: Optional[List[str]] = None):
+def run_symilar(argv: Optional[Sequence[str]] = None):
"""Run symilar
Arguments can be a list of strings normally supplied as arguments on the command line
"""
from pylint.checkers.similar import Run as SimilarRun
- SimilarRun(arguments or sys.argv[1:])
+ SimilarRun(argv or sys.argv[1:])
def modify_sys_path() -> None:
@@ -11,22 +11,22 @@
"""Run pylint
- Arguments can be a list of strings normally supplied as arguments on the command line
+ argv can be a sequence of strings normally supplied as arguments on the command line
"""
from pylint.lint import Run as PylintRun
@@ -37,24 +37,24 @@ def run_epylint():
"""Run pyreverse
- Arguments can be a list of strings normally supplied as arguments on the command line
+ argv can be a sequence of strings normally supplied as arguments on the command line
"""
from pylint.pyreverse.main import Run as PyreverseRun
@@ -37,24 +37,24 @@ def run_epylint():
"""Run symilar
- Arguments can be a list of strings normally supplied as arguments on the command line
+ argv can be a sequence of strings normally supplied as arguments on the command line
"""
from pylint.checkers.similar import Run as SimilarRun